export P=exiv2
export V=0.26
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

if ! [ -d ../exiv2 ]; then
	cd ..
	git clone --branch $V https://github.com/Exiv2/exiv2.git
	cd exiv4
	git apply ../osgeo4w/patch
	cd osgeo4w
fi

if ! [ -d "$OSGEO4W_REP" ]; then
	echo no repository
	exit 1
fi

fetchenv() {
	local IFS
	IFS=
	batch=$1
	shift

	if ! [ -f "$batch" ]; then
		echo "$batch not found"
		return 1
	fi

	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
	cmd /c set >$srcenv
	cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
	/usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
	s/\\\\/\\//g;
	s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
	s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
	/usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
	. $diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export CMAKE_GEN="Visual Studio 14 2015"
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			export CMAKE_GEN="Visual Studio 14 2015 Win64"
			;;

		*)
			echo invalid arch
			exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R/$P-devel $R/$P-tools

		cat <<EOF >$R/setup.hint
sdesc: "Image metadata library"
ldesc: "Image metadata library"
maintainer: JuergenFischer
category: Libs
requires: msvcrt2015 expat zlib
EOF

		cat <<EOF >$R/$P-devel/setup.hint
sdesc: "Image metadata library (development)"
ldesc: "Image metadata library (development)"
maintainer: JuergenFischer
category: Libs
requires: exiv2
EOF

		cat <<EOF >$R/$P-tools/setup.hint
sdesc: "Image metadata library (tools)"
ldesc: "Image metadata library (tools)"
maintainer: JuergenFischer
category: Libs
requires: exiv2
EOF

		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"

		export BUILDCONF=RelWithDebInfo
		mkdir -p build-$ARCH install-$ARCH
		cd build-$ARCH

		cmake -G "$CMAKE_GEN" \
			-DCMAKE_CONFIGURATION_TYPES=$BUILDCONF \
			-DCMAKE_INSTALL_PREFIX=../install-$ARCH \
			../../exiv2

		for i in ZERO_CHECK ALL_BUILD INSTALL; do
			echo "$i: $(date)"
			cmake --build . --target $i --config $BUILDCONF
		done

		cd ..

		/bin/tar -C install-$ARCH -cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 include lib
		/bin/tar -C install-$ARCH -cjf $R/$P-tools/$P-tools-$V-$B.tar.bz2 --exclude "*.dll" bin
		/bin/tar -C install-$ARCH -cjf $R/$P-$V-$B.tar.bz2 --exclude "*.exe" bin
		/bin/tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/patch
	)
done

date
